import {
  Metadata, Loader, IEventParam, Http, IDictionary, dayjs as moment, I18n,
} from '@zeedhi/core';
import {
  Select, TreeGridEditable, Form, DialogService, Button, TextInput, Tabs, GridEditable,
  LoadingService,
} from '@zeedhi/common';

export class Pla01300DadosReceitaController {
  public crudController = Loader.getInstance('CrudController');

  private utilities = Loader.getInstance('Utilities');

  public gridEditController = Loader.getInstance('GridEditableController');

  public appController = Loader.getInstance('AppController');
  
  public setNameTab: string = '';
  
  public isNew = true;
  
  public qtdLiqBrut: string = '';
  
  public qtdPessoa: string[] = [];

  public oldQtd: any;
  
  public getParamPlaneja() {
    const form = Metadata.getInstance<Form>('formUnidade');
    const cdfilial = form.value.UNIDADEFORM.CDFILIAL;
    
    LoadingService.show(' ');
    this.utilities.getParamPlaneja(cdfilial).then((paramplaneja: IDictionary) => {
      this.qtdLiqBrut = paramplaneja?.IDQTLIQUBRUT;
      LoadingService.hide();
    });
  }
  
  public setNameTabRecipe() {
    const tabPratos: Tabs = Metadata.getInstance('tabPratos');
    if (tabPratos.name === 'tabPratos') {
      if (tabPratos.activeTab === 2) this.setNameTab = 'subTabReceitaPadrao';
      else if (tabPratos.activeTab === 3) this.setNameTab = 'subTabReceitaTipoCard';
      else if (tabPratos.activeTab === 4) this.setNameTab = 'subTabReceitaLocal';
      else if (tabPratos.activeTab === 5) this.setNameTab = 'subTabReceitaServico';
      else if (tabPratos.activeTab === 6) this.setNameTab = 'subTabReceitaPadraoQualidade';
      else if (tabPratos.activeTab === 7) this.setNameTab = 'subTabReceitaRegiao';
    }
  }
  
  public gridProductSelected() {
    const tab = this.setNameTab;
    let grid: any;
    if (tab === 'subTabReceitaPadrao') grid = Metadata.getInstance('RECIPE_STANDARD');
    else if (tab === 'subTabReceitaLocal') grid = Metadata.getInstance('RECIPE_LOCAL');
    else if (tab === 'subTabReceitaServico') grid = Metadata.getInstance('RECIPE_SERVICE');
    else if (tab === 'subTabReceitaTipoCard') grid = Metadata.getInstance('RECIPE_TIPOCARD');
    else if (tab === 'subTabReceitaPadraoQualidade') grid = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
    else if (tab === 'subTabReceitaRegiao') grid = Metadata.getInstance('RECIPE_REGION');
    return grid;
  }
  
  public setProductProdution({ component }: IEventParam<Select>) {
    const grid = this.gridProductSelected();
    
    if (grid) {
      const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
      const currentRow = plateTree.datasource.currentRow;
      const conditions = [
        {
          name: 'CDPRATO',
          operator: '=',
          value: currentRow.CDPRATO,
        },
        {
          name: 'CDPRODUTO',
          operator: '=',
          value: grid.datasource.currentRow.CDPRATO,
        },
        {
          name: 'CDFILAUXPRAT',
          operator: '=',
          value: currentRow.CDFILAUXPRAT,
        },
        {
          name: 'TCDPRODUTO',
          operator: '=',
          value: 'T',
        },
      ];
      
      component.datasource.filter = conditions;
      component.datasource.get();
      this.disableButtonsRecipeFalse();
    }
  }
  
  public async validProductionProduct() {
    const grid = this.gridProductSelected();
    // if (component.value !== null) {
    let receita: any;
    let formDadosRecipe: any;
    let formTransportada: any;

    if (grid.name === 'RECIPE_STANDARD') {
      receita = 'P';
      formDadosRecipe = Metadata.getInstance<Form>('formDadosReceita');
      formTransportada = Metadata.getInstance<Form>('formRefeicoesTransp');
    } else if (grid.name === 'RECIPE_LOCAL') {
      receita = 'F';
      formDadosRecipe = Metadata.getInstance<Form>('formDadosReceitaLocal');
      formTransportada = Metadata.getInstance<Form>('formRefeicoesTranspLocal');
    } else if (grid.name === 'RECIPE_SERVICE') {
      receita = 'S';
      formDadosRecipe = Metadata.getInstance<Form>('formDadosReceitaServico');
      formTransportada = Metadata.getInstance<Form>('formRefeicoesTranspServico');
    }
    
    const rowDadosRecipe = formDadosRecipe.value;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRow = plateTree.datasource.currentRow;
    rowDadosRecipe.CDPRODUTO = formTransportada.value.CDPRODPRODUCAO;
    rowDadosRecipe.CDPRATO = currentRow.CDPRATO;
    rowDadosRecipe.CDFILAUXPRAT = currentRow.CDFILAUXPRAT;
    rowDadosRecipe.RECEITA = receita;
    
    let valid = true;
    if (formTransportada.value.CDPRODPRODUCAO !== null) {
      await Http.post('/prato/validProductionProduct', { rowDadosRecipe }).then((callback) => {
        const result = callback.data.dataset.result;
        if (result.length > 0) {
          let receitas = '';
          result.forEach((item: IDictionary) => {
            if (item.TIPO === 'P') receitas += `${I18n.translate('Padrão')}: `;
            else if (item.TIPO === 'F') receitas += `${I18n.translate('Local')} (${item.CDFILIAL}): `;
            else if (item.TIPO === 'S') {
              receitas += `${I18n.translate('Serviço')} (${item.CDFILIAL}|${item.CDSERVFILI}): `;
            }
            receitas += `${this.utilities.getValueWithMaskPrato(item.CDPRATO)} - ${item.NMPRATO}\n`;
          });
          this.utilities.showAlert(
            'alertError',
            I18n.translate('O produto de produção já está sendo usado na(s) seguinte(s) receita(s): {{PARAM1}}.',
              { PARAM1: receitas }), 'error',
          );
          formTransportada.value.CDPRODPRODUCAO = '';
          valid = false;
        }
        // return true;
      });
    } else if (grid.name === 'RECIPE_LOCAL') {
      formTransportada.value.IDFINALFILI = 'M';
      formTransportada.value.IDPRODCHILL = 'N';
      formTransportada.value.QTLIMSEGFILI = 0;
      formTransportada.value.IDTPPRODCHILL = 'NENHUM';
    } else if (grid.name === 'RECIPE_SERVICE') {
      formTransportada.value.IDFINALSERV = 'M';
      formTransportada.value.IDPRODCHILL = 'N';
      formTransportada.value.QTLIMSEGSERV = 0;
      formTransportada.value.IDTPPRODCHILL = 'NENHUM';
    } else if (grid.name === 'RECIPE_STANDARD') {
      formTransportada.value.IDFINALPADR = 'M';
      formTransportada.value.IDPRODCHILL = 'N';
      formTransportada.value.QTLIMSEGPADR = 0;
      formTransportada.value.IDTPPRODCHILL = 'NENHUM';
    }
    return valid;
  }
  
  public get visibleField() {
    const nameTab = this.setNameTab;
    if (nameTab === 'subTabReceitaRegiao' || nameTab === 'subTabReceitaPadraoQualidade') return false;
    return true;
  }
  
  public defaultStatus({ component }: IEventParam<Select>) {
    if (component.value === undefined || component.value === '' || component.value === null) component.value = 'S';
  }
  
  public defaultFinishing({ component }: IEventParam<Select>) {
    if (component.value === undefined || component.value === '' || component.value === null) component.setValue('M');
  }
  
  public defaultCookChill({ component }: IEventParam<Select>) {
    if (component.value === undefined || component.value === '' || component.value === null) component.setValue('N');
  }
  
  public validationCookChill({ component }: IEventParam<Select>) {
    const tab = this.setNameTab;
    let antecipacao;
    let armazenamento;
    let antecipacaoValueForm;
    let amazenamentoValueForm;
    if (tab === 'subTabReceitaPadrao') {
      const rowRefeicoesTransp = Metadata.getInstance<Form>('formRefeicoesTransp');
      antecipacao = Metadata.getInstance<TextInput>('QTLIMSEGPADR');
      armazenamento = rowRefeicoesTransp.getChildInstance<Select>('IDTPPRODCHILL');
      antecipacaoValueForm = rowRefeicoesTransp.value.QTLIMSEGPADR;
      amazenamentoValueForm = rowRefeicoesTransp.value.IDTPPRODCHILL;
    } else if (tab === 'subTabReceitaLocal') {
      const refTranspLocal = Metadata.getInstance<Form>('formRefeicoesTranspLocal');
      antecipacao = Metadata.getInstance<TextInput>('QTLIMSEGFILI');
      armazenamento = refTranspLocal.getChildInstance<Select>('IDTPPRODCHILL');
      antecipacaoValueForm = refTranspLocal.value.QTLIMSEGFILI;
      amazenamentoValueForm = refTranspLocal.value.IDTPPRODCHILL;
    } else if (tab === 'subTabReceitaServico') {
      const refTranspServico = Metadata.getInstance<Form>('formRefeicoesTranspServico');
      antecipacao = Metadata.getInstance<TextInput>('QTLIMSEGSERV');
      armazenamento = refTranspServico.getChildInstance<Select>('IDTPPRODCHILL');
      antecipacaoValueForm = refTranspServico.value.QTLIMSEGSERV;
      amazenamentoValueForm = refTranspServico.value.IDTPPRODCHILL;
    }
    // const armazenamento = Metadata.getInstance<Select>('IDTPPRODCHILL');
    
    if (antecipacao && armazenamento) {
      if (component.value === 'S') {
        antecipacao.disabled = false;
        armazenamento.disabled = false;
        if ((amazenamentoValueForm === null || amazenamentoValueForm === undefined)
          && (antecipacaoValueForm === null || antecipacaoValueForm === undefined)) {
          antecipacao.value = '0';
          armazenamento.value = 'NENHUM';
        }
      } else {
        antecipacao.disabled = true;
        antecipacao.value = '0';
        antecipacao.removeValidation('required');
        armazenamento.disabled = true;
        armazenamento.value = 'NENHUM';
        armazenamento.removeValidation('required');
      }
    }
  }

  public calculateQtyPerson({ component }: IEventParam<Button>) {
    let qtAtiva = '';
    const grid = this.gridProductSelected();
    const QTDRECEITA = this.qtdLiqBrut;
    const prodReceita = grid.datasource.data;
    
    if (grid.name === 'RECIPE_STANDARD') {
      // sem essas linhas comentadas o calculo fica diferente do calculo feito pela ação em Prato
      // if (QTDRECEITA === 'B') qtAtiva = 'QTBRUTAPRUNR';
      // else qtAtiva = 'QTPRODPRAT';
      qtAtiva = 'QTPRODPRAT';
    } else if (grid.name === 'RECIPE_TIPOCARD') {
      const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
      const tipocard = formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD;
      if (tipocard === undefined) {
        this.utilities.showAlert('alert', 'O Tipo de Cardápio deve ser informado.', 'error');
        return;
      }
      
      // if (QTDRECEITA === 'B') qtAtiva = 'QTBRUTAPRTP';
      // else qtAtiva = 'QTPRODPRATTP';
      qtAtiva = 'QTPRODPRATTP';
    } else if (grid.name === 'RECIPE_LOCAL') {
      const formFiltroLocal = Metadata.getInstance<Form>('FORM_LOCAL');
      const cdfilial = formFiltroLocal.value.BRANCH_LOCAL?.CDFILIAL;
      if (cdfilial === undefined) {
        this.utilities.showAlert('alert', 'Unidade deve ser informado.', 'error');
        return;
      }
      if (QTDRECEITA === 'B') qtAtiva = 'QTBRUTALOUNR';
      else qtAtiva = 'QTPRODRECLOC';
    } else if (grid.name === 'RECIPE_SERVICE') {
      const formFiltroServico = Metadata.getInstance<Form>('FORM_SERVICE');
      const cdserv = formFiltroServico.value.SERVICE?.CDSERVFILI;
      if (cdserv === undefined) {
        this.utilities.showAlert('alert', 'Unidade e serviço devem ser informados.', 'error');
        return;
      }
      // if (QTDRECEITA === 'B') qtAtiva = 'QTBRUTASEUNR';
      // else qtAtiva = 'QTPRODRECSER';
      qtAtiva = 'QTPRODRECSER';
    } else if (grid.name === 'RECIPE_PADRAOQUALIDADE') {
      const formFiltroPadrQual = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
      const padrQual = formFiltroPadrQual.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
      if (padrQual === undefined) {
        this.utilities.showAlert('alert', 'O Padrão de Qualidade deve ser informado.', 'error');
        return;
      }
      // if (QTDRECEITA === 'B') qtAtiva = 'QTBRUTAPADQUNR';
      // else qtAtiva = 'QTPRODRECPADQ';
      qtAtiva = 'QTPRODRECPADQ';
    } else if (grid.name === 'RECIPE_REGION') {
      const formFiltroRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
      const padrQual = formFiltroRegiao.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
      const regiao = formFiltroRegiao.value.NMREGIAO?.CDREGIAO;
      if (padrQual === undefined || regiao === undefined) {
        this.utilities.showAlert('alert', 'Padrão de Qualidade/Região devem ser informados.', 'error');
        return;
      }
      // if (QTDRECEITA === 'B') qtAtiva = 'QTBRUTAREGIAOUNR';
      // else qtAtiva = 'QTPRODRECREGIAO';
      qtAtiva = 'QTPRODRECREGIAO';
    }
    
    this.returnFatConversao(prodReceita, qtAtiva, component);
  }
  
  public formDadosPrato() {
    const tab = this.setNameTab;
    let form: any;
    
    if (tab === 'subTabReceitaPadrao') form = Metadata.getInstance('formDadosReceita');
    else if (tab === 'subTabReceitaLocal') form = Metadata.getInstance('formDadosReceitaLocal');
    else if (tab === 'subTabReceitaServico') form = Metadata.getInstance('formDadosReceitaServico');
    else if (tab === 'subTabReceitaTipoCard') form = Metadata.getInstance('formDadosReceitaTipoCard');
    else if (tab === 'subTabReceitaPadraoQualidade') form = Metadata.getInstance('formDadosReceitaPadraoQualidade');
    else if (tab === 'subTabReceitaRegiao') form = Metadata.getInstance('formDadosReceitaRegiao');
    return form;
  }
  
  public returnFatConversao(prodReceita: any, qtAtiva: any, component: any) {
    const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
    const sgUnidade = formDadosPlate.value.DSUNIDADEDP;
    Http.post('/prato/returnFatConversao', { prodReceita, qtAtiva, sgUnidade }).then((callback) => {
      const qtdPessoa = callback.data.dataset.QTPESSOA;
      const qtdPessoaFormatter = this.utilities.formatValuesToFixed(qtdPessoa[0], 5);
      DialogService.show({
        name: 'pesoCalculadoPrato',
        type: 'warning',
        title: 'Atenção',
        text: I18n.translate('Peso calculado do prato é {{PARAM1}}. Confirma?', { PARAM1: [qtdPessoaFormatter] }),
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.saveCalculo(qtdPessoa, component) },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    });
  }
  
  public saveCalculo(qtdPessoa: any, component: any) {
    // const form = this.formDadosPrato();
    // if (form.name === 'formDadosReceita') form.value.QTPADRAOPRAT = qtdPessoa[0].toFixed(5);
    // else if (form.name === 'formDadosReceitaLocal') form.value.QTPADRAOFILI = qtdPessoa[0].toFixed(5);
    // else if (form.name === 'formDadosReceitaServico') form.value.QTPADRAOSERV = qtdPessoa[0].toFixed(5);
    // else if (form.name === 'formDadosReceitaTipoCard') form.value.QTPADRAOPRATTP = qtdPessoa[0].toFixed(5);
    // else if (form.name === 'formDadosReceitaPadraoQualidade') form.value.QTPADRAOPADQ = qtdPessoa[0].toFixed(5);
    // else if (form.name === 'formDadosReceitaRegiao') form.value.QTPADRAOREGIAO = qtdPessoa[0].toFixed(5);
    
    this.qtdPessoa = qtdPessoa[0];
    this.salvaDadosRecipePlate(component);
    // this.utilities.showAlert('alert', 'Calculado com Sucesso.', 'success');
    DialogService.hide();
  }
  
  public async salvaDadosRecipePlate({ component }: any) {
    const tab = this.setNameTab;
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRowTree = plateTree.datasource.currentRow;
    let row: any;
    
    if (tab === 'subTabReceitaPadrao' || tab === 'subTabReceitaLocal' || tab === 'subTabReceitaServico') {
      const valid = await this.validProductionProduct();
      if (!valid) return;
    }

    if (this.validDateInactivation()) {
      if (tab === 'subTabReceitaPadrao') row = this.saveRecipePadrao(currentRowTree);
      else if (tab === 'subTabReceitaLocal') row = this.saveRecipeLocal(currentRowTree);
      else if (tab === 'subTabReceitaServico') row = this.saveRecipeService(currentRowTree);
      else if (tab === 'subTabReceitaTipoCard') row = this.saveRecipeTpCard(currentRowTree);
      else if (tab === 'subTabReceitaPadraoQualidade') row = this.saveRecipePadraoQualidade(currentRowTree);
      else if (tab === 'subTabReceitaRegiao') row = this.saveRecipeRegiao(currentRowTree);
      
      if (row !== false) {
        await Http.post('/prato/saveRecipePlate', { requestType: 'Row', row }).then(() => {
          this.utilities.showAlert('alert', 'Salvo com sucesso!', 'success');
          if (row.PERCENTUAL !== null && row.PERCENTUAL !== 1 && component !== 'ZdButton') {
            this.dialogQtyAdjustment(row, currentRowTree, true);
          }
        }).catch((error) => {
          this.utilities.showAlert('alertError', error, 'error');
        }).finally(() => {
          this.setValuesRecipe();
          this.disableButtonsRecipeTrue();
        });
      }
    }
  }
  
  public saveRecipePadrao(currentRowTree: any) {
    const formDadosRecipe = Metadata.getInstance<Form>('formDadosReceita');
    const rowDadosRecipe = formDadosRecipe.value;
    const rowRefeicoesTransp = Metadata.getInstance<Form>('formRefeicoesTransp').value;
    const rowDadosTransporte = Metadata.getInstance<Form>('formDadosTransporte').value;

    if (rowDadosRecipe.QTPADRAOPRAT === null || rowDadosRecipe.QTPADRAOPRAT === undefined) rowDadosRecipe.QTPADRAOPRAT = 0;

    if (formDadosRecipe.validate()) {
      const plate = currentRowTree.CDPRATO;
      const filAux = currentRowTree.CDFILAUXPRAT;
      
      rowDadosRecipe.VRPEMINPADR = rowDadosRecipe.VRPEMINPADR ? rowDadosRecipe.VRPEMINPADR : 0;
      
      const row = { ...rowDadosRecipe };
      
      const oldQtd = this.oldQtd;
      if (rowDadosRecipe.QTPADRAOPRAT === undefined) rowDadosRecipe.QTPADRAOPRAT = 0;
      row.PERCENTUAL = oldQtd > 0 ? rowDadosRecipe.QTPADRAOPRAT / oldQtd : null;
      
      if (this.qtdPessoa.length !== 0) {
        row.QTPADRAOPRAT = this.qtdPessoa;
        this.qtdPessoa = [];
      } else if (typeof row.QTPADRAOPRAT === 'string') {
        row.QTPADRAOPRAT = rowDadosRecipe.QTPADRAOPRAT ? parseFloat(rowDadosRecipe.QTPADRAOPRAT.replaceAll(',', '.')) : [];
      } else row.QTPADRAOPRAT = rowDadosRecipe.QTPADRAOPRAT ? rowDadosRecipe.QTPADRAOPRAT : [];
      
      row.CDPRATO = plate;
      row.CDFILAUXPRAT = filAux;
      row.TIPORECEITA = 'P';
      row.QTMEDICASEPRATPADR = rowDadosRecipe.QTMEDICASEPRATPADR ? rowDadosRecipe.QTMEDICASEPRATPADR : null;
      row.QTCONTAIPRAT = rowDadosTransporte.QTCONTAIPRAT ? rowDadosTransporte.QTCONTAIPRAT : '';
      row.VRPEMINPADR = rowDadosTransporte.VRPEMINPADR ? rowDadosTransporte.VRPEMINPADR : '';
      row.QTAMOSTRPADR = rowDadosTransporte.QTAMOSTRPADR ? rowDadosTransporte.QTAMOSTRPADR : '';
      row.IDFINALPADR = rowRefeicoesTransp.IDFINALPADR ? rowRefeicoesTransp.IDFINALPADR : 'M';
      row.CDPRODPRODUCAO = rowRefeicoesTransp.CDPRODPRODUCAO ? rowRefeicoesTransp.CDPRODPRODUCAO : '';
      row.CDPRODUTO = rowRefeicoesTransp.CDPRODPRODUCAO ? rowRefeicoesTransp.CDPRODPRODUCAO.CDPRODUTO : '';
      row.NRCORPRIPRAT = rowDadosRecipe.NRCORPRIPRAT ? this.hexToRGB(rowDadosRecipe.NRCORPRIPRAT) : '';
      row.HRVALCONPRAT = rowDadosRecipe.HRVALCONPRAT ? this.calculateHour(rowDadosRecipe.HRVALCONPRAT) : '';
      row.DTINATIVAUTO = rowDadosRecipe.DTINATIVAUTO ? rowDadosRecipe.DTINATIVAUTO : '';
      row.__is_new = this.isNew;
      
      if (rowRefeicoesTransp.IDPRODCHILL === 'S') {
        if (rowRefeicoesTransp.QTLIMSEGPADR < 0) {
          this.utilities.showAlert('alert', 'Antecipação deve ser maior que zero.', 'warning');
          return false;
        } if (rowRefeicoesTransp.QTLIMSEGPADR === undefined) {
          this.utilities.showAlert('alert', 'Obrigatório preenchimento da Antecipação.', 'warning');
          return false;
        } if (rowRefeicoesTransp.IDTPPRODCHILL === undefined) {
          this.utilities.showAlert('alert', 'Obrigatório preenchimento do Tipo de Armazenamento.', 'warning');
          return false;
        }
      }
      
      if (row.CDMEDICASE !== null && row.QTMEDICASEPRATPADR === null) {
        this.utilities.showAlert('alert', 'Obrigatório preenchimento da Quantidade.', 'warning');
        return false;
      }
      
      if (row.QTMEDICASEPRATPADR !== null && row.QTMEDICASEPRATPADR < 0) {
        this.utilities.showAlert('alert', 'Quantidade deve ser maior que zero.', 'warning');
        return false;
      }
      
      row.IDPRODCHILL = rowRefeicoesTransp.IDPRODCHILL ? rowRefeicoesTransp.IDPRODCHILL : 'N';
      if (rowRefeicoesTransp.IDPRODCHILL === 'N') {
        row.QTLIMSEGPADR = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      } else {
        row.QTLIMSEGPADR = rowRefeicoesTransp.QTLIMSEGPADR ? rowRefeicoesTransp.QTLIMSEGPADR : '';
        row.IDTPPRODCHILL = rowRefeicoesTransp.IDTPPRODCHILL ? rowRefeicoesTransp.IDTPPRODCHILL : '';
      }
      
      if (rowRefeicoesTransp.CDPRODPRODUCAO === '' || rowRefeicoesTransp.CDPRODPRODUCAO === null) {
        row.IDFINALPADR = 'M';
        row.IDPRODCHILL = 'N';
        row.QTLIMSEGPADR = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      }
      
      if (rowDadosTransporte.QTCONTAIPRAT < 0) {
        this.utilities.showAlert('alert', 'Quantidade por Container não pode ser negativo', 'warning');
        return false;
      }
      
      if (rowDadosTransporte.VRPEMINPADR < 0) {
        this.utilities.showAlert('alert', 'Mínimo por Container (%) não pode ser negativo.', 'warning');
        return false;
      }
      
      if (rowDadosTransporte.QTAMOSTRPADR < 0) {
        this.utilities.showAlert('alert', 'Amostra não pode ser negativo.', 'warning');
        return false;
      }
      
      return row;
    } return false;
  }
  
  public saveRecipeLocal(currentRowTree: any) {
    const form = Metadata.getInstance<Form>('formDadosReceitaLocal');
    const formLocal = form.value;
    const refTranspLocal = Metadata.getInstance<Form>('formRefeicoesTranspLocal').value;
    const tranpLocal = Metadata.getInstance<Form>('formDadosTransporteLocal').value;
    const formFiltroLocal = Metadata.getInstance<Form>('FORM_LOCAL');
    const row = { ...formLocal };
    
    if (formLocal.QTPADRAOFILI === null || formLocal.QTPADRAOFILI === undefined) formLocal.QTPADRAOFILI = 0;
    
    if (form.validate()) {
      row.CDFILIAL = formFiltroLocal.value.BRANCH_LOCAL?.CDFILIAL;
      if (row.CDFILIAL === undefined) {
        this.utilities.showAlert('alert', 'Unidade deve ser informado.', 'error');
        return false;
      }
      
      row.TIPORECEITA = 'L';
      row.CDPRATO = currentRowTree.CDPRATO;
      row.CDFILAUXPRAT = currentRowTree.CDFILAUXPRAT;
      
      row.CDPRODPRODUCAO = refTranspLocal.CDPRODPRODUCAO ? refTranspLocal.CDPRODPRODUCAO : '';

      if (this.qtdPessoa.length !== 0) {
        row.QTPADRAOFILI = this.qtdPessoa;
        this.qtdPessoa = [];
      } else if (typeof row.QTPADRAOFILI === 'string') {
        row.QTPADRAOFILI = formLocal.QTPADRAOFILI ? parseFloat(formLocal.QTPADRAOFILI.replaceAll(',', '.')) : [];
      } else row.QTPADRAOFILI = formLocal.QTPADRAOFILI ? formLocal.QTPADRAOFILI : [];
      
      const oldQtd = this.oldQtd;
      if (formLocal.QTPADRAOFILI === undefined) formLocal.QTPADRAOFILI = 0;
      row.PERCENTUAL = oldQtd > 0 ? formLocal.QTPADRAOFILI / oldQtd : null;
      
      row.QTMEDICASEPRATFILI = formLocal.QTMEDICASEPRATFILI ? formLocal.QTMEDICASEPRATFILI : null;
      row.QTCONTAIFILI = tranpLocal.QTCONTAIFILI ? parseFloat(tranpLocal.QTCONTAIFILI).toFixed(5) : '';
      row.VRPEMINFILI = tranpLocal.VRPEMINFILI ? tranpLocal.VRPEMINFILI : '';
      row.QTAMOSTRFILI = tranpLocal.QTAMOSTRFILI ? tranpLocal.QTAMOSTRFILI : '';
      row.NMFANTASIAPF = formLocal.NMFANTASIAPF ? formLocal.NMFANTASIAPF : '';
      row.HRVALCONFILI = formLocal.HRVALCONFILI ? this.calculateHour(formLocal.HRVALCONFILI) : '';
      row.NRCORPRIFILI = formLocal.NRCORPRIFILI ? this.hexToRGB(formLocal.NRCORPRIFILI) : '';
      
      if (refTranspLocal.IDPRODCHILL === 'S') {
        if (refTranspLocal.QTLIMSEGFILI < 0) {
          this.utilities.showAlert('alert', 'Antecipação deve ser maior que zero.', 'warning');
          return false;
        } if (refTranspLocal.QTLIMSEGFILI === undefined) {
          this.utilities.showAlert('alert', 'Obrigatório preenchimento da Antecipação.', 'warning');
          return false;
        } if (refTranspLocal.IDTPPRODCHILL === undefined) {
          this.utilities.showAlert('alert', 'Obrigatório preenchimento do Tipo de Armazenamento.', 'warning');
          return false;
        }
      }
      
      if (row.CDMEDICASE !== null && row.QTMEDICASEPRATFILI === null) {
        this.utilities.showAlert('alert', 'Obrigatório preenchimento da Quantidade.', 'warning');
        return false;
      }
      
      if (row.CDMEDICASE !== null && row.QTMEDICASEPRATFILI < 0) {
        this.utilities.showAlert('alert', 'Quantidade deve ser maior que zero.', 'warning');
        return false;
      }
      
      row.IDFINALFILI = refTranspLocal.IDFINALFILI ? refTranspLocal.IDFINALFILI : 'M';
      row.IDPRODCHILL = refTranspLocal.IDPRODCHILL ? refTranspLocal.IDPRODCHILL : 'N';
      if (refTranspLocal.IDPRODCHILL === 'N') {
        row.QTLIMSEGFILI = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      } else {
        row.QTLIMSEGFILI = refTranspLocal.QTLIMSEGFILI ? refTranspLocal.QTLIMSEGFILI : '';
        row.IDTPPRODCHILL = refTranspLocal.IDTPPRODCHILL ? refTranspLocal.IDTPPRODCHILL : '';
      }
      
      if (refTranspLocal.CDPRODPRODUCAO === '' || refTranspLocal.CDPRODPRODUCAO === null) {
        row.IDFINALFILI = 'M';
        row.IDPRODCHILL = 'N';
        row.QTLIMSEGFILI = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      }
      
      if (tranpLocal.QTCONTAIFILI < 0) {
        this.utilities.showAlert('alert', 'Quantidade por Container não pode ser negativo', 'warning');
        return false;
      }
      
      if (tranpLocal.VRPEMINFILI < 0) {
        this.utilities.showAlert('alert', 'Mínimo por Container (%) não pode ser negativo.', 'warning');
        return false;
      }
      
      if (tranpLocal.QTAMOSTRFILI < 0) {
        this.utilities.showAlert('alert', 'Amostra não pode ser negativo.', 'warning');
        return false;
      }
      
      row.__is_new = this.isNew;
      return row;
    } return false;
  }
  
  public saveRecipeService(currentRowTree: any) {
    const form = Metadata.getInstance<Form>('formDadosReceitaServico');
    const formServico = form.value;
    const refTranspServico = Metadata.getInstance<Form>('formRefeicoesTranspServico').value;
    const tranpServico = Metadata.getInstance<Form>('formDadosTransporteServico').value;
    const formFiltroServ = Metadata.getInstance<Form>('FORM_SERVICE');
    
    if (formServico.QTPADRAOSERV === null || formServico.QTPADRAOSERV === undefined) formServico.QTPADRAOSERV = 0;
    
    if (form.validate()) {
      const row = { ...formServico };
      
      row.TIPORECEITA = 'S';
      row.CDFILIAL = formFiltroServ.value.BRANCH_SERVICE?.CDFILIAL;
      row.CDSERVFILI = formFiltroServ.value.SERVICE?.CDSERVFILI;
      if (row.CDSERVFILI === undefined) {
        this.utilities.showAlert('alert', 'Unidade e serviço devem ser informados.', 'error');
        return false;
      }
      
      row.CDPRATO = currentRowTree.CDPRATO;
      row.CDFILAUXPRAT = currentRowTree.CDFILAUXPRAT;
      
      // row.CDMEDICASE = formServico.CDMEDICASE ? formServico.CDMEDICASE : '';
      row.CDPRODPRODUCAO = refTranspServico.CDPRODPRODUCAO ? refTranspServico.CDPRODPRODUCAO : '';
      
      if (this.qtdPessoa.length !== 0) {
        row.QTPADRAOSERV = this.qtdPessoa;
        this.qtdPessoa = [];
      } else if (typeof row.QTPADRAOSERV === 'string') {
        row.QTPADRAOSERV = formServico.QTPADRAOSERV ? parseFloat(formServico.QTPADRAOSERV.replaceAll(',', '.')) : [];
      } else row.QTPADRAOSERV = formServico.QTPADRAOSERV ? formServico.QTPADRAOSERV : [];
      
      const oldQtd = this.oldQtd;
      if (formServico.QTPADRAOSERV === undefined) formServico.QTPADRAOSERV = 0;
      row.PERCENTUAL = oldQtd > 0 ? formServico.QTPADRAOSERV / oldQtd : null;
      row.NMFANTASIASE = formServico.NMFANTASIASE ? formServico.NMFANTASIASE : '';
      row.QTMEDICASEPRATSERV = formServico.QTMEDICASEPRATSERV ? formServico.QTMEDICASEPRATSERV : null;
      row.QTCONTAISERV = tranpServico.QTCONTAISERV ? tranpServico.QTCONTAISERV : '';
      row.VRPEMINSERV = tranpServico.VRPEMINSERV ? tranpServico.VRPEMINSERV : '';
      row.QTAMOSTRSERV = tranpServico.QTAMOSTRSERV ? tranpServico.QTAMOSTRSERV : '';
      
      if (refTranspServico.IDPRODCHILL === 'N') {
        row.QTLIMSEGSERV = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      }

      if (refTranspServico.IDPRODCHILL === 'S') {
        if (refTranspServico.QTLIMSEGSERV < 0) {
          this.utilities.showAlert('alert', 'Antecipação deve ser maior que zero.', 'warning');
          return false;
        } if (refTranspServico.QTLIMSEGSERV === undefined) {
          this.utilities.showAlert('alert', 'Obrigatório preenchimento da Antecipação.', 'warning');
          return false;
        } if (refTranspServico.IDTPPRODCHILL === undefined) {
          this.utilities.showAlert('alert', 'Obrigatório preenchimento do Tipo de Armazenamento.', 'warning');
          return false;
        }
      }
      
      if (row.CDMEDICASE !== null && row.QTMEDICASEPRATSERV === null) {
        this.utilities.showAlert('alert', 'Obrigatório preenchimento da Quantidade.', 'warning');
        return false;
      }
      
      if (row.CDMEDICASE !== null && row.QTMEDICASEPRATSERV < 0) {
        this.utilities.showAlert('alert', 'Quantidade deve ser maior que zero.', 'warning');
        return false;
      }
      
      row.IDFINALSERV = refTranspServico.IDFINALSERV ? refTranspServico.IDFINALSERV : 'M';
      row.IDPRODCHILL = refTranspServico.IDPRODCHILL ? refTranspServico.IDPRODCHILL : 'N';
      if (refTranspServico.IDPRODCHILL === 'N') {
        row.QTLIMSEGSERV = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      } else {
        row.QTLIMSEGSERV = refTranspServico.QTLIMSEGSERV ? refTranspServico.QTLIMSEGSERV : '';
        row.IDTPPRODCHILL = refTranspServico.IDTPPRODCHILL ? refTranspServico.IDTPPRODCHILL : '';
      }
      
      if (refTranspServico.CDPRODPRODUCAO === '' || refTranspServico.CDPRODPRODUCAO === null) {
        row.IDFINALSERV = 'M';
        row.IDPRODCHILL = 'N';
        row.QTLIMSEGSERV = 0;
        row.IDTPPRODCHILL = 'NENHUM';
      }
      
      if (tranpServico.QTCONTAISERV < 0) {
        this.utilities.showAlert('alert', 'Quantidade por Container não pode ser negativo', 'warning');
        return false;
      }
      
      if (tranpServico.VRPEMINSERV < 0) {
        this.utilities.showAlert('alert', 'Mínimo por Container (%) não pode ser negativo.', 'warning');
        return false;
      }
      
      if (tranpServico.QTAMOSTRSERV < 0) {
        this.utilities.showAlert('alert', 'Amostra não pode ser negativo.', 'warning');
        return false;
      }
      
      row.HRVALCONSERV = formServico.HRVALCONSERV ? this.calculateHour(formServico.HRVALCONSERV) : '';
      row.NRCORPRISERV = formServico.NRCORPRISERV ? this.hexToRGB(formServico.NRCORPRISERV) : '';
      row.__is_new = this.isNew;
      return row;
    } return false;
  }
  
  public saveRecipeTpCard(currentRowTree: any) {
    const form = Metadata.getInstance<Form>('formDadosReceitaTipoCard');
    const formTipoCard = form.value;
    const tranpTipoCard = Metadata.getInstance<Form>('formDadosTransporteTipoCard').value;
    const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
    const row = { ...formTipoCard };
    
    if (formTipoCard.QTPADRAOPRATTP === null || formTipoCard.QTPADRAOPRATTP === undefined) formTipoCard.QTPADRAOPRATTP = 0;
    
    if (form.validate()) {
      row.TIPORECEITA = 'C';
      row.CDTIPOCARD = formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD;
      if (row.CDTIPOCARD === undefined) {
        this.utilities.showAlert('alert', 'O Tipo de Cardápio deve ser informado.', 'error');
        return false;
      }
      
      row.CDPRATO = currentRowTree.CDPRATO;
      row.CDFILAUXPRAT = currentRowTree.CDFILAUXPRAT;
      
      if (this.qtdPessoa.length !== 0) {
        row.QTPADRAOPRATTP = this.qtdPessoa;
        this.qtdPessoa = [];
      } else if (typeof row.QTPADRAOPRATTP === 'string') {
        row.QTPADRAOPRATTP = formTipoCard.QTPADRAOPRATTP ? parseFloat(formTipoCard.QTPADRAOPRATTP.replaceAll(',', '.')) : [];
      } else row.QTPADRAOPRATTP = formTipoCard.QTPADRAOPRATTP ? formTipoCard.QTPADRAOPRATTP : [];
      
      if (formTipoCard.QTPADRAOPRATTP === undefined) formTipoCard.QTPADRAOPRATTP = 0;
      
      const oldQtd = this.oldQtd;
      row.PERCENTUAL = oldQtd > 0 ? formTipoCard.QTPADRAOPRATTP / oldQtd : null;
      
      row.NMFANTASIAPRTP = formTipoCard.NMFANTASIAPRTP ? formTipoCard.NMFANTASIAPRTP : '';
      row.DSPRATO = formTipoCard.DSPRATO ? formTipoCard.DSPRATO : '';
      row.QTCONTAIPRATTP = tranpTipoCard.QTCONTAIPRATTP ? tranpTipoCard.QTCONTAIPRATTP : '';
      row.VRPEMINPADRTP = tranpTipoCard.VRPEMINPADRTP ? tranpTipoCard.VRPEMINPADRTP : '';
      row.QTAMOSTRPADRTP = tranpTipoCard.QTAMOSTRPADRTP ? tranpTipoCard.QTAMOSTRPADRTP : '';
      
      row.HRVALCONPRATTP = formTipoCard.HRVALCONPRATTP ? this.calculateHour(formTipoCard.HRVALCONPRATTP) : '';
      row.NRCORPRIPRATTP = formTipoCard.NRCORPRIPRATTP ? this.hexToRGB(formTipoCard.NRCORPRIPRATTP) : '';
      row.CDFILCENTPME = this.appController.getCdCentral();
      
      if (tranpTipoCard.QTCONTAIPRATTP < 0) {
        this.utilities.showAlert('alert', 'Quantidade por Container não pode ser negativo', 'warning');
        return false;
      }
      
      if (tranpTipoCard.VRPEMINPADRTP < 0) {
        this.utilities.showAlert('alert', 'Mínimo por Container (%) não pode ser negativo.', 'warning');
        return false;
      }
      
      if (tranpTipoCard.QTAMOSTRPADRTP < 0) {
        this.utilities.showAlert('alert', 'Amostra não pode ser negativo.', 'warning');
        return false;
      }
      
      row.__is_new = this.isNew;
      return row;
    } return false;
  }
  
  public saveRecipePadraoQualidade(currentRowTree: any) {
    const form = Metadata.getInstance<Form>('formDadosReceitaPadraoQualidade');
    const formPadrQual = form.value;
    const formFiltroPadrQual = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
    const row = { ...formPadrQual };
    
    if (formPadrQual.QTPADRAOPADQ === null || formPadrQual.QTPADRAOPADQ === undefined) formPadrQual.QTPADRAOPADQ = 0;
    
    if (form.validate()) {
      row.TIPORECEITA = 'Q';
      row.NRPADRAOQUALIDADE = formFiltroPadrQual.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
      if (row.NRPADRAOQUALIDADE === undefined) {
        this.utilities.showAlert('alert', 'O Padrão de Qualidade deve ser informado.', 'error');
        return false;
      }
      
      row.CDPRATO = currentRowTree.CDPRATO;
      row.CDFILAUXPRAT = currentRowTree.CDFILAUXPRAT;
      
      if (this.qtdPessoa.length !== 0) {
        row.QTPADRAOPADQ = this.qtdPessoa;
        this.qtdPessoa = [];
      } else if (typeof row.QTPADRAOPADQ === 'string') {
        row.QTPADRAOPADQ = formPadrQual.QTPADRAOPADQ ? parseFloat(formPadrQual.QTPADRAOPADQ.replaceAll(',', '.')) : [];
      } else row.QTPADRAOPADQ = formPadrQual.QTPADRAOPADQ ? formPadrQual.QTPADRAOPADQ : [];
      
      const oldQtd = this.oldQtd;
      if (formPadrQual.QTPADRAOPADQ === undefined) formPadrQual.QTPADRAOPADQ = 0;
      row.PERCENTUAL = oldQtd > 0 ? formPadrQual.QTPADRAOPADQ / oldQtd : null;
      
      row.NRCORPRIPADQ = formPadrQual.NRCORPRIPADQ ? this.hexToRGB(formPadrQual.NRCORPRIPADQ) : '';
      row.CDFILCENTPME = this.appController.getCdCentral();
      
      row.__is_new = this.isNew;
      return row;
    } return false;
  }
  
  public saveRecipeRegiao(currentRowTree: any) {
    const form = Metadata.getInstance<Form>('formDadosReceitaRegiao');
    const formRegiao = form.value;
    const formFiltroRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
    const row = { ...formRegiao };
    
    if (formRegiao.QTPADRAOREGIAO === null || formRegiao.QTPADRAOREGIAO === undefined) formRegiao.QTPADRAOREGIAO = 0;
    
    if (form.validate()) {
      row.TIPORECEITA = 'R';
      row.NRPADRAOQUALIDADE = formFiltroRegiao.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
      row.CDREGIAO = formFiltroRegiao.value.NMREGIAO?.CDREGIAO;
      
      if (row.NRPADRAOQUALIDADE === undefined || row.CDREGIAO === undefined) {
        this.utilities.showAlert('alert', 'Padrão de Qualidade/Região devem ser informados.', 'error');
        return false;
      }
      
      row.CDPRATO = currentRowTree.CDPRATO;
      row.CDFILAUXPRAT = currentRowTree.CDFILAUXPRAT;
      
      if (this.qtdPessoa.length !== 0) {
        row.QTPADRAOREGIAO = this.qtdPessoa;
        this.qtdPessoa = [];
      } else if (typeof row.QTPADRAOREGIAO === 'string') {
        row.QTPADRAOREGIAO = formRegiao.QTPADRAOREGIAO ? parseFloat(formRegiao.QTPADRAOREGIAO.replaceAll(',', '.')) : [];
      } else row.QTPADRAOREGIAO = formRegiao.QTPADRAOREGIAO ? formRegiao.QTPADRAOREGIAO : [];

      const oldQtd = this.oldQtd;
      if (formRegiao.QTPADRAOREGIAO === undefined) formRegiao.QTPADRAOREGIAO = 0;
      row.PERCENTUAL = oldQtd > 0 ? formRegiao.QTPADRAOREGIAO / oldQtd : null;
        
      row.NRCORPRIREGIAO = formRegiao.NRCORPRIREGIAO ? this.hexToRGB(formRegiao.NRCORPRIREGIAO) : '';
      row.CDFILCENTPME = this.appController.getCdCentral();
      
      row.__is_new = this.isNew;
      return row;
    } return false;
  }
  
  public dialogQtyAdjustment(row: any, currentRowTree: any, is_adjust_person_qt: any) {
    if (row.PERCENTUAL > 0) {
      DialogService.show({
        name: 'qtyAdjustment',
        type: 'warning',
        title: 'Atenção',
        text: I18n.translate('Deseja alterar proporcionalmente as quantidades dos produtos na receita?'),
        buttons: [
          {
            name: 'yesAdjustment',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.saveQtyAdjustment(row, currentRowTree, is_adjust_person_qt) },
            outline: true,
          },
          {
            name: 'noAdjustment',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
          {
            name: 'progressLine',
            component: 'ZdProgress',
            label: 'Progress',
            indeterminate: true,
            cssClass: 'loading-progress-line',
          },
        ],
      });
    }
  }
  
  public saveQtyAdjustment(row: any, currentRowTree: any, is_adjust_person_qt = false) {
    if (row.PERCENTUAL > 0) {
      const tipoReceita = row.TIPORECEITA;
      const qtAtiva = this.qtdLiqBrut;
      const formDadosPlate = Metadata.getInstance<Form>('formDadosPrato');
      const sgUnidade = formDadosPlate.value.DSUNIDADEDP;
      
      let nrpadraoqualidade = 0;
      let cdregiao = 0;
      
      let filial;
      let servico;
      let cardapio;
      let wdgtReceita;
      
      if (row.PERCENTUAL > 0) {
        if (tipoReceita === 'P') {
          wdgtReceita = Metadata.getInstance('RECIPE_STANDARD');
          filial = null;
          servico = null;
          cardapio = null;
        } else if (tipoReceita === 'L') {
          wdgtReceita = Metadata.getInstance('RECIPE_LOCAL');
          const formFiltroLocal = Metadata.getInstance<Form>('FORM_LOCAL');
          filial = formFiltroLocal.value.BRANCH_LOCAL?.CDFILIAL ? formFiltroLocal.value.BRANCH_LOCAL?.CDFILIAL : null;
          servico = null;
          cardapio = null;
        } else if (tipoReceita === 'S') {
          wdgtReceita = Metadata.getInstance('RECIPE_SERVICE');
          const formFiltroServico = Metadata.getInstance<Form>('FORM_SERVICE');
          filial = formFiltroServico.value.BRANCH_SERVICE?.CDFILIAL
            ? formFiltroServico.value.BRANCH_SERVICE?.CDFILIAL
            : null;
          servico = formFiltroServico.value.SERVICE?.CDSERVFILI ? formFiltroServico.value.SERVICE?.CDSERVFILI : null;
          cardapio = null;
        } else if (tipoReceita === 'C') {
          wdgtReceita = Metadata.getInstance('RECIPE_TIPOCARD');
          const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
          filial = null;
          servico = null;
          cardapio = formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD ? formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD : null;
        } else if (tipoReceita === 'Q') {
          wdgtReceita = Metadata.getInstance('RECIPE_PADRAOQUALIDADE');
          const formFiltroPadq = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
          filial = null;
          servico = null;
          nrpadraoqualidade = formFiltroPadq.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE
            ? formFiltroPadq.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE
            : null;
        } else if (tipoReceita === 'R') {
          wdgtReceita = Metadata.getInstance('RECIPE_REGION');
          const formFiltroRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
          filial = null;
          servico = null;
          nrpadraoqualidade = formFiltroRegiao.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE
            ? formFiltroRegiao.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE
            : null;
          cdregiao = formFiltroRegiao.value.NMREGIAO?.CDREGIAO ? formFiltroRegiao.value.NMREGIAO?.CDREGIAO : null;
        }
        
        const newRow = {
          CDPRATO: currentRowTree.CDPRATO,
          CDFILAUXPRAT: currentRowTree.CDFILAUXPRAT,
          SGUNIDADE: sgUnidade,
          CDFILIAL: filial,
          CDSERVFILI: servico,
          CDTIPOCARD: cardapio,
          CDPRODUTO: 'X',
          PERCENTUAL: row.PERCENTUAL,
          QTATIVA: qtAtiva,
          TPOPERACAO: 'M',
          TIPORECEITA: row.TIPORECEITA,
          NRPADRAOQUALIDADE: nrpadraoqualidade,
          CDREGIAO: cdregiao,
          IS_ADJUST_PERSON_QT: is_adjust_person_qt,
          CDFILCENTPME: this.appController.getCdCentral(),
        };
        
        this.confirmAltProp(wdgtReceita, newRow);
      } else this.utilities.showAlert('alert', 'Valor do ajuste deve ser maior que zero', 'error');
    }
  }
  
  public confirmAltProp(wdgtReceita: any, newRow: any) {
    // const buttonYes = Metadata.getInstance<Button>('yesAdjustment');
    const tab = this.setNameTab;
    let gridReload: any;
    
    LoadingService.show(' ');
    Http.post('/dadosReceita/alterProp', { newRow }).then(() => {
      this.utilities.showAlert('alert', 'Processo realizado com sucesso.', 'success');
      if (tab === 'subTabReceitaPadrao') gridReload = Metadata.getInstance<GridEditable>('RECIPE_STANDARD');
      else if (tab === 'subTabReceitaLocal') gridReload = Metadata.getInstance<GridEditable>('RECIPE_LOCAL');
      else if (tab === 'subTabReceitaServico') gridReload = Metadata.getInstance<GridEditable>('RECIPE_SERVICE');
      else if (tab === 'subTabReceitaTipoCard') gridReload = Metadata.getInstance<GridEditable>('RECIPE_TIPOCARD');
      else if (tab === 'subTabReceitaPadraoQualidade') {
        gridReload = Metadata.getInstance<GridEditable>('RECIPE_PADRAOQUALIDADE');
      } else if (tab === 'subTabReceitaRegiao') gridReload = Metadata.getInstance<GridEditable>('RECIPE_REGION');
      this.gridEditController.reload({ component: gridReload });
    }).catch((error: string) => {
      this.utilities.showAlert('alertError', `pme::${error}`, 'error');
      DialogService.hide();
    }).finally(() => {
      DialogService.hide();
      LoadingService.hide();
    });
  }
  
  public hexToRGB(corHex: any) {
    const corRgb = this.utilities.hexToRgbInline(corHex).split('.', 3);
    const rgb = this.utilities.RGBToTColor(corRgb[0], corRgb[1], corRgb[2]);
    return rgb;
  }
  
  public calculateHour(fieldHour: any) {
    const replacehHour = fieldHour.replace(':', '');
    const minutes = replacehHour.substr(-2);
    const hour = replacehHour.substr(0, 2);
    const total = (parseInt(hour, 10) + (minutes / 60));
    const totalFormat = this.utilities.formatValuesToFixed(total, 5);
    return totalFormat.replace(',', '.');
  }
  
  public setValuesRecipe() {
    const plateTree = Metadata.getInstance<TreeGridEditable>('plateTreeGrid');
    const currentRowTree = plateTree.datasource.currentRow;
    const tab = this.setNameTab;
    
    const plate = currentRowTree.CDPRATO;
    const filAux = currentRowTree.CDFILAUXPRAT;
    
    if (tab === 'subTabReceitaPadrao') {
      if (document.getElementsByName('formDadosReceita').length > 0) {
        const form = Metadata.getInstance<Form>('formDadosReceita');
        const rowDadosRecipe = Metadata.getInstance<Form>('formDadosReceita').value;
        const rowRefeicoesTransp = Metadata.getInstance<Form>('formRefeicoesTransp').value;
        const rowDadosTransporte = Metadata.getInstance<Form>('formDadosTransporte').value;
        const medCase = form.getChildInstance<Select>('CDMEDICASE');
        const prodAcabado = Metadata.getInstance<Form>('formRefeicoesTransp').getChildInstance<Select>('CDPRODPRODUCAO');
        
        const filter: IDictionary = [];
        this.utilities.onMountedFilterFind(filter, 'CDPRATO', '=', plate);
        this.utilities.onMountedFilterFind(filter, 'CDFILAUXPRAT', '=', filAux);
        LoadingService.show(' ');
        Http.post('/find/pratoPratpadrProdacabado', { requestType: 'FilterData', filter }).then((callback) => {
          const result = callback.data.data;
          if (result.length > 0) {
            this.isNew = false;
            const formatHour = result[0].HRVALCONPRAT ? this.formatHour(result[0].HRVALCONPRAT) : null;
            
            if (result[0].CDMEDICASE) {
              const medidaCaseira = {
                NMMEDICASE: result[0].NMMEDICASE,
                CDMEDICASE: result[0].CDMEDICASE,
              };
              medCase.datasource.data = [medidaCaseira];
              medCase.setValue(result[0].CDMEDICASE);
            } else rowDadosRecipe.CDMEDICASE = '';
  
            rowDadosRecipe.NMFANTASIAPR = result[0].NMFANTASIAPR;
            rowDadosRecipe.NRCORPRIPRAT = this.utilities.TColorToHex(result[0].NRCORPRIPRAT);
            rowDadosRecipe.HRVALCONPRAT = formatHour;
            rowDadosRecipe.QTPADRAOPRAT = result[0].QTPADRAOPRAT !== null
              ? this.utilities.formatValuesToFixed(result[0].QTPADRAOPRAT, 5)
              : null;
            rowDadosRecipe.IDATIVO = result[0].IDATIVO;
            rowDadosRecipe.DTINATIVAUTO = result[0].DTINATIVAUTO
              ? moment(result[0].DTINATIVAUTO, 'DD/MM/YYYY').format(this.utilities.getFormatLocale())
              : '';
            rowDadosRecipe.DSPRATO = result[0].DSPRATO;
            rowDadosRecipe.QTMEDICASEPRATPADR = result[0].QTMEDICASEPRATPADR;
            
            this.oldQtd = result[0].QTPADRAOPRAT;
            
            if (result[0].CDPRODPRODUCAO) {
              const prodPA = {
                NMPRODUTO: result[0].NMPRODUTO,
                CDPRODUTO: result[0].CDPRODPRODUCAO,
                CDARVPROD: result[0].CDARVPROD,
              };
              prodAcabado.datasource.data = [prodPA];
              prodAcabado.setValue(result[0].CDPRODPRODUCAO);
            } else rowRefeicoesTransp.CDPRODPRODUCAO = '';
  
            rowRefeicoesTransp.IDFINALPADR = result[0].IDFINALPADR;
            rowRefeicoesTransp.IDPRODCHILL = result[0].IDPRODCHILL;
            rowRefeicoesTransp.QTLIMSEGPADR = result[0].QTLIMSEGPADR;
            rowRefeicoesTransp.IDTPPRODCHILL = result[0].IDTPPRODCHILL;
            rowDadosTransporte.QTCONTAIPRAT = result[0].QTCONTAIPRAT;
            rowDadosTransporte.VRPEMINPADR = result[0].VRPEMINPADR;
            rowDadosTransporte.QTAMOSTRPADR = result[0].QTAMOSTRPADR;
          } else {
            this.isNew = true;
            rowDadosRecipe.NMFANTASIAPR = '';
            rowDadosRecipe.NRCORPRIPRAT = '#FFFFFF';
            rowDadosRecipe.HRVALCONPRAT = '';
            rowDadosRecipe.QTPADRAOPRAT = 0;
            rowDadosRecipe.IDATIVO = 'S';
            rowDadosRecipe.DTINATIVAUTO = '';
            rowDadosRecipe.DSPRATO = '';
            rowDadosRecipe.CDMEDICASE = '';
            rowDadosRecipe.QTMEDICASEPRATPADR = '0';
            rowRefeicoesTransp.CDPRODPRODUCAO = '';
            rowRefeicoesTransp.IDFINALPADR = 'M';
            rowRefeicoesTransp.IDPRODCHILL = 'N';
            rowRefeicoesTransp.QTLIMSEGPADR = '0';
            rowRefeicoesTransp.IDTPPRODCHILL = 'NENHUM';
            rowDadosTransporte.QTCONTAIPRAT = '0';
            rowDadosTransporte.VRPEMINPADR = '0';
            rowDadosTransporte.QTAMOSTRPADR = '0';
          }
          LoadingService.hide();
        });
      }
    } else if (tab === 'subTabReceitaLocal') {
      if (document.getElementsByName('formDadosReceitaLocal').length > 0) {
        const form = Metadata.getInstance<Form>('formDadosReceitaLocal');
        const formLocal = Metadata.getInstance<Form>('formDadosReceitaLocal').value;
        const refTranspLocal = Metadata.getInstance<Form>('formRefeicoesTranspLocal').value;
        const tranpLocal = Metadata.getInstance<Form>('formDadosTransporteLocal').value;
        const medCase = form.getChildInstance<Select>('CDMEDICASE');
        const prodAcabado = Metadata.getInstance<Form>(
          'formRefeicoesTranspLocal',
        ).getChildInstance<Select>('CDPRODPRODUCAO');
        
        const formFiltroLocal = Metadata.getInstance<Form>('FORM_LOCAL');
        const cdfilial = formFiltroLocal.value.BRANCH_LOCAL?.CDFILIAL;
        if (cdfilial === undefined) {
          this.utilities.showAlert('alert', 'Unidade deve ser informado.', 'error');
          
          formLocal.NMFANTASIAPF = '';
          formLocal.NRCORPRIFILI = '#FFFFFF';
          formLocal.HRVALCONFILI = '';
          formLocal.QTPADRAOFILI = 0;
          formLocal.IDATIVO = '';
          formLocal.DTINATIVAUTO = '';
          formLocal.DSPRATO = '';
          formLocal.CDMEDICASE = '';
          formLocal.QTMEDICASEPRATFILI = 0;
          refTranspLocal.CDPRODPRODUCAO = '';
          refTranspLocal.IDFINALFILI = 'M';
          refTranspLocal.IDPRODCHILL = 'N';
          refTranspLocal.QTLIMSEGFILI = 0;
          refTranspLocal.IDTPPRODCHILL = 'NENHUM';
          tranpLocal.QTCONTAIFILI = 0;
          tranpLocal.VRPEMINFILI = 0;
          tranpLocal.QTAMOSTRFILI = 0;
          
          return;
        }
        
        const filter: IDictionary = [];
        this.utilities.onMountedFilterFind(filter, 'CDPRATO', '=', plate);
        this.utilities.onMountedFilterFind(filter, 'CDFILAUXPRAT', '=', filAux);
        this.utilities.onMountedFilterFind(filter, 'CDFILIAL', '=', cdfilial);
        LoadingService.show(' ');
        Http.post('/find/pratFiliProdAcabado', { requestType: 'FilterData', filter }).then((callback) => {
          const result = callback.data.data;
          if (result.length > 0) {
            this.isNew = false;
            const formatHour = result[0].HRVALCONFILI ? this.formatHour(result[0].HRVALCONFILI) : null;
            if (result[0].CDMEDICASE) {
              const medidaCaseira = {
                NMMEDICASE: result[0].NMMEDICASE,
                CDMEDICASE: result[0].CDMEDICASE,
              };
              medCase.datasource.data = [medidaCaseira];
              medCase.setValue(result[0].CDMEDICASE);
            } else formLocal.CDMEDICASE = '';
            
            formLocal.NMFANTASIAPF = result[0].NMFANTASIAPF;
            formLocal.NRCORPRIFILI = this.utilities.TColorToHex(result[0].NRCORPRIFILI);
            formLocal.HRVALCONFILI = formatHour;
            formLocal.QTPADRAOFILI = result[0].QTPADRAOFILI !== null
              ? this.utilities.formatValuesToFixed(result[0].QTPADRAOFILI, 5)
              : null;
            formLocal.IDATIVO = result[0].IDATIVO;
            formLocal.DTINATIVAUTO = result[0].DTINATIVAUTO
              ? moment(result[0].DTINATIVAUTO, 'DD/MM/YYYY').format(this.utilities.getFormatLocale())
              : '';
            formLocal.DSPRATO = result[0].DSPRATO;
            formLocal.QTMEDICASEPRATFILI = result[0].QTMEDICASEPRATFILI;
            
            this.oldQtd = result[0].QTPADRAOFILI;
            
            if (result[0].CDPRODPRODUCAO) {
              const prodPA = {
                NMPRODUTO: result[0].NMPRODUTO,
                CDPRODUTO: result[0].CDPRODPRODUCAO,
                CDARVPROD: result[0].CDARVPROD,
              };
              prodAcabado.datasource.data = [prodPA];
              prodAcabado.setValue(result[0].CDPRODPRODUCAO);
            } else refTranspLocal.CDPRODPRODUCAO = '';
            
            refTranspLocal.IDFINALFILI = result[0].IDFINALFILI;
            refTranspLocal.IDPRODCHILL = result[0].IDPRODCHILL;
            refTranspLocal.QTLIMSEGFILI = result[0].QTLIMSEGFILI;
            refTranspLocal.IDTPPRODCHILL = result[0].IDTPPRODCHILL;
            tranpLocal.QTCONTAIFILI = result[0].QTCONTAIFILI;
            tranpLocal.VRPEMINFILI = result[0].VRPEMINFILI;
            tranpLocal.QTAMOSTRFILI = result[0].QTAMOSTRFILI;
          } else {
            this.isNew = true;
            
            formLocal.NMFANTASIAPF = '';
            formLocal.NRCORPRIFILI = '#FFFFFF';
            formLocal.HRVALCONFILI = '';
            formLocal.QTPADRAOFILI = 0;
            formLocal.IDATIVO = 'S';
            formLocal.DTINATIVAUTO = '';
            formLocal.DSPRATO = '';
            formLocal.CDMEDICASE = '';
            formLocal.QTMEDICASEPRATFILI = 0;
            refTranspLocal.CDPRODPRODUCAO = '';
            refTranspLocal.IDFINALFILI = 'M';
            refTranspLocal.IDPRODCHILL = 'N';
            refTranspLocal.QTLIMSEGFILI = 0;
            refTranspLocal.IDTPPRODCHILL = 'NENHUM';
            tranpLocal.QTCONTAIFILI = 0;
            tranpLocal.VRPEMINFILI = 0;
            tranpLocal.QTAMOSTRFILI = 0;
          }
          LoadingService.hide();
        });
      }
    } else if (tab === 'subTabReceitaServico') {
      if (document.getElementsByName('formDadosReceitaServico').length > 0) {
        const form = Metadata.getInstance<Form>('formDadosReceitaServico');
        const formServico = Metadata.getInstance<Form>('formDadosReceitaServico').value;
        const refTranspServico = Metadata.getInstance<Form>('formRefeicoesTranspServico').value;
        const tranpServico = Metadata.getInstance<Form>('formDadosTransporteServico').value;
        const medCase = form.getChildInstance<Select>('CDMEDICASE');
        const prodAcabado = Metadata.getInstance<Form>(
          'formRefeicoesTranspServico',
        ).getChildInstance<Select>('CDPRODPRODUCAO');
        
        const formFiltroServico = Metadata.getInstance<Form>('FORM_SERVICE');
        const cdfilial = formFiltroServico.value.BRANCH_SERVICE?.CDFILIAL;
        const cdserv = formFiltroServico.value.SERVICE?.CDSERVFILI;
        if (cdserv === undefined) {
          this.utilities.showAlert('alert', 'Unidade e serviço devem ser informados.', 'error');
          
          formServico.NMFANTASIASE = '';
          formServico.NRCORPRISERV = '#FFFFFF';
          formServico.HRVALCONSERV = '';
          formServico.QTPADRAOSERV = 0;
          formServico.IDATIVO = '';
          formServico.DTINATIVAUTO = '';
          formServico.DSPRATO = '';
          formServico.CDMEDICASE = '';
          formServico.QTMEDICASEPRATSERV = 0;
          refTranspServico.CDPRODPRODUCAO = '';
          refTranspServico.IDFINALSERV = 'M';
          refTranspServico.IDPRODCHILL = 'N';
          refTranspServico.QTLIMSEGSERV = 0;
          refTranspServico.IDTPPRODCHILL = 'NENHUM';
          tranpServico.QTCONTAISERV = 0;
          tranpServico.VRPEMINSERV = 0;
          tranpServico.QTAMOSTRSERV = 0;
  
          return;
        }
        
        const filter: IDictionary = [];
        this.utilities.onMountedFilterFind(filter, 'CDPRATO', '=', plate);
        this.utilities.onMountedFilterFind(filter, 'CDFILAUXPRAT', '=', filAux);
        this.utilities.onMountedFilterFind(filter, 'CDFILIAL', '=', cdfilial);
        this.utilities.onMountedFilterFind(filter, 'CDSERVFILI', '=', cdserv);
        LoadingService.show(' ');
        Http.post('/find/pratServProdAcabado', { requestType: 'FilterData', filter }).then((callback) => {
          const result = callback.data.data;
          if (result.length > 0) {
            this.isNew = false;
            const formatHour = result[0].HRVALCONSERV ? this.formatHour(result[0].HRVALCONSERV) : null;
            if (result[0].CDMEDICASE) {
              const medidaCaseira = {
                NMMEDICASE: result[0].NMMEDICASE,
                CDMEDICASE: result[0].CDMEDICASE,
              };
              medCase.datasource.data = [medidaCaseira];
              medCase.setValue(result[0].CDMEDICASE);
            } else formServico.CDMEDICASE = '';
            
            formServico.NMFANTASIASE = result[0].NMFANTASIASE;
            formServico.NRCORPRISERV = this.utilities.TColorToHex(result[0].NRCORPRISERV);
            formServico.HRVALCONSERV = formatHour;
            formServico.QTPADRAOSERV = result[0].QTPADRAOSERV !== null
              ? this.utilities.formatValuesToFixed(result[0].QTPADRAOSERV, 5)
              : null;
            formServico.IDATIVO = result[0].IDATIVO;
            formServico.DTINATIVAUTO = result[0].DTINATIVAUTO
              ? moment(result[0].DTINATIVAUTO, 'DD/MM/YYYY').format(this.utilities.getFormatLocale())
              : '';
            formServico.DSPRATO = result[0].DSPRATO;
            formServico.QTMEDICASEPRATSERV = result[0].QTMEDICASEPRATSERV;
            
            this.oldQtd = result[0].QTPADRAOSERV;
            
            if (result[0].CDPRODPRODUCAO) {
              const prodPA = {
                NMPRODUTO: result[0].NMPRODUTO,
                CDPRODUTO: result[0].CDPRODPRODUCAO,
                CDARVPROD: result[0].CDARVPROD,
              };
              prodAcabado.datasource.data = [prodPA];
              prodAcabado.setValue(result[0].CDPRODPRODUCAO);
            } else refTranspServico.CDPRODPRODUCAO = '';
            
            refTranspServico.IDFINALSERV = result[0].IDFINALSERV;
            refTranspServico.IDPRODCHILL = result[0].IDPRODCHILL;
            refTranspServico.QTLIMSEGSERV = result[0].QTLIMSEGSERV;
            refTranspServico.IDTPPRODCHILL = result[0].IDTPPRODCHILL;
            tranpServico.QTCONTAISERV = result[0].QTCONTAISERV;
            tranpServico.VRPEMINSERV = result[0].VRPEMINSERV;
            tranpServico.QTAMOSTRSERV = result[0].QTAMOSTRSERV;
          } else {
            this.isNew = true;
            formServico.IDATIVO = 'S';
            formServico.QTMEDICASEPRATSERV = '0';
            formServico.NRCORPRISERV = '#FFFFFF';
            tranpServico.QTCONTAISERV = 0;
            formServico.NMFANTASIASE = '';
            formServico.HRVALCONSERV = '';
            formServico.QTPADRAOSERV = 0;
            formServico.DTINATIVAUTO = '';
            formServico.DSPRATO = '';
            formServico.CDMEDICASE = '';
            refTranspServico.CDPRODPRODUCAO = '';
            refTranspServico.IDFINALSERV = 'M';
            refTranspServico.IDPRODCHILL = 'N';
            refTranspServico.QTLIMSEGSERV = 0;
            refTranspServico.IDTPPRODCHILL = 'NENHUM';
            tranpServico.VRPEMINSERV = 0;
            tranpServico.QTAMOSTRSERV = 0;
          }
          LoadingService.hide();
        });
      }
    } else if (tab === 'subTabReceitaTipoCard') {
      if (document.getElementsByName('formDadosReceitaTipoCard').length > 0) {
        const formTipoCard = Metadata.getInstance<Form>('formDadosReceitaTipoCard').value;
        const tranpTipoCard = Metadata.getInstance<Form>('formDadosTransporteTipoCard').value;
        
        const formFiltroTpCard = Metadata.getInstance<Form>('FORM_TIPOCARD');
        const tipocard = formFiltroTpCard.value.TIPOCARD?.CDTIPOCARD;
        const central = formFiltroTpCard.value.CENTRAL;
        if (tipocard === undefined) {
          this.utilities.showAlert('alert', 'O Tipo de Cardápio deve ser informado.', 'error');
          
          formTipoCard.NMFANTASIAPRTP = '';
          formTipoCard.NRCORPRIPRATTP = '#FFFFFF';
          formTipoCard.HRVALCONPRATTP = '';
          formTipoCard.QTPADRAOPRATTP = 0;
          formTipoCard.IDATIVO = '';
          formTipoCard.DTINATIVAUTO = '';
          formTipoCard.DSPRATO = '';
          tranpTipoCard.QTCONTAIPRATTP = 0;
          tranpTipoCard.VRPEMINPADRTP = 0;
          tranpTipoCard.QTAMOSTRPADRTP = 0;
          
          return;
        }
        LoadingService.show(' ');
        Http.post('/prattpcard', {
          central, plate, filAux, tipocard,
        }).then((callback) => {
          const result = callback.data.dataset.columnsToReturn;
          if (result.length > 0) {
            this.isNew = false;
            const formatHour = result[0].HRVALCONPRATTP ? this.formatHour(result[0].HRVALCONPRATTP) : null;
            formTipoCard.NMFANTASIAPRTP = result[0].NMFANTASIAPRTP;
            formTipoCard.NRCORPRIPRATTP = this.utilities.TColorToHex(result[0].NRCORPRIPRATTP);
            formTipoCard.HRVALCONPRATTP = formatHour;
            formTipoCard.QTPADRAOPRATTP = result[0].QTPADRAOPRATTP !== null
              ? this.utilities.formatValuesToFixed(result[0].QTPADRAOPRATTP, 5)
              : null;
            this.oldQtd = result[0].QTPADRAOPRATTP;
            formTipoCard.IDATIVO = result[0].IDATIVO;
            formTipoCard.DTINATIVAUTO = result[0].DTINATIVAUTO
              ? moment(result[0].DTINATIVAUTO, 'DD/MM/YYYY').format(this.utilities.getFormatLocale())
              : '';
            formTipoCard.DSPRATO = result[0].DSPRATO;
            tranpTipoCard.QTCONTAIPRATTP = result[0].QTCONTAIPRATTP;
            tranpTipoCard.VRPEMINPADRTP = result[0].VRPEMINPADRTP;
            tranpTipoCard.QTAMOSTRPADRTP = result[0].QTAMOSTRPADRTP;
          } else {
            this.isNew = true;
            formTipoCard.NMFANTASIAPRTP = '';
            formTipoCard.NRCORPRIPRATTP = '#FFFFFF';
            formTipoCard.HRVALCONPRATTP = '';
            formTipoCard.QTPADRAOPRATTP = 0;
            formTipoCard.IDATIVO = 'S';
            formTipoCard.DTINATIVAUTO = '';
            formTipoCard.DSPRATO = '';
            tranpTipoCard.QTCONTAIPRATTP = '0';
            tranpTipoCard.VRPEMINPADRTP = '0';
            tranpTipoCard.QTAMOSTRPADRTP = '0';
          }
          LoadingService.hide();
        });
      }
    } else if (tab === 'subTabReceitaPadraoQualidade') {
      if (document.getElementsByName('formDadosReceitaPadraoQualidade').length > 0) {
        const formPadrQual = Metadata.getInstance<Form>('formDadosReceitaPadraoQualidade').value;
        const formFiltroPadrQual = Metadata.getInstance<Form>('FORM_PADRAOQUALIDADE');
        const padrQual = formFiltroPadrQual.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
        if (padrQual === undefined) {
          this.utilities.showAlert('alert', 'O Padrão de Qualidade deve ser informado.', 'error');
          
          formPadrQual.NRCORPRIPADQ = '#FFFFFF';
          formPadrQual.QTPADRAOPADQ = 0;
          formPadrQual.DTINATIVAUTO = '';
          
          return;
        }
        
        const filter: IDictionary = [];
        this.utilities.onMountedFilterFind(filter, 'CDPRATO', '=', plate);
        this.utilities.onMountedFilterFind(filter, 'CDFILAUXPRAT', '=', filAux);
        this.utilities.onMountedFilterFind(filter, 'NRPADRAOQUALIDADE', '=', padrQual);
        LoadingService.show(' ');
        Http.post('/find/pratpadqualiProdAcabado', { requestType: 'FilterData', filter }).then((callback) => {
          const result = callback.data.data;
          if (result.length > 0) {
            this.isNew = false;
            formPadrQual.NRCORPRIPADQ = this.utilities.TColorToHex(result[0].NRCORPRIPADQ);
            formPadrQual.QTPADRAOPADQ = result[0].QTPADRAOPADQ !== null
              ? this.utilities.formatValuesToFixed(result[0].QTPADRAOPADQ, 5)
              : '';
            this.oldQtd = result[0].QTPADRAOPADQ;
            formPadrQual.IDATIVO = result[0].IDATIVO;
            formPadrQual.DTINATIVAUTO = result[0].DTINATIVAUTO
              ? moment(result[0].DTINATIVAUTO, 'DD/MM/YYYY').format(this.utilities.getFormatLocale())
              : '';
            formPadrQual.NRPRATPADQUALI = result[0].NRPRATPADQUALI;
          } else {
            this.isNew = true;
            formPadrQual.NRCORPRIPADQ = '#FFFFFF';
            formPadrQual.NRPRATPADQUALI = '';
            formPadrQual.DTINATIVAUTO = '';
            formPadrQual.QTPADRAOPADQ = '';
          }
          LoadingService.hide();
        });
      }
    } else if (tab === 'subTabReceitaRegiao') {
      if (document.getElementsByName('formDadosReceitaRegiao').length > 0) {
        const formRegiao = Metadata.getInstance<Form>('formDadosReceitaRegiao').value;
        const formFiltroRegiao = Metadata.getInstance<Form>('FORM_REGIAO');
        const padrQual = formFiltroRegiao.value.NMPADRAOQUALIDADE?.NRPADRAOQUALIDADE;
        const regiao = formFiltroRegiao.value.NMREGIAO?.CDREGIAO;
        
        if (padrQual === undefined || regiao === undefined) {
          this.utilities.showAlert('alert', 'Padrão de Qualidade/Região devem ser informados.', 'error');
          
          formRegiao.NRCORPRIREGIAO = '#FFFFFF';
          formRegiao.QTPADRAOREGIAO = 0;
          formRegiao.DTINATIVAUTO = '';
          
          return;
        }
        
        const filter: IDictionary = [];
        this.utilities.onMountedFilterFind(filter, 'CDPRATO', '=', plate);
        this.utilities.onMountedFilterFind(filter, 'CDFILAUXPRAT', '=', filAux);
        this.utilities.onMountedFilterFind(filter, 'NRPADRAOQUALIDADE', '=', padrQual);
        this.utilities.onMountedFilterFind(filter, 'CDREGIAO', '=', regiao);
        LoadingService.show(' ');
        Http.post('/find/pratregiaoProdAcabado', { requestType: 'FilterData', filter }).then((callback) => {
          const result = callback.data.data;
          if (result.length > 0) {
            this.isNew = false;
            formRegiao.NRCORPRIREGIAO = this.utilities.TColorToHex(result[0].NRCORPRIREGIAO);
            if (result[0].QTPADRAOREGIAO !== null) {
              formRegiao.QTPADRAOREGIAO = this.utilities.formatValuesToFixed(result[0].QTPADRAOREGIAO, 5);
            } else formRegiao.QTPADRAOREGIAO = result[0].QTPADRAOREGIAO;
            
            formRegiao.NRPRATREGIAO = result[0].NRPRATREGIAO;
            this.oldQtd = result[0].QTPADRAOREGIAO;
            formRegiao.IDATIVO = result[0].IDATIVO;
            formRegiao.DTINATIVAUTO = result[0].DTINATIVAUTO
              ? moment(result[0].DTINATIVAUTO, 'DD/MM/YYYY').format(this.utilities.getFormatLocale())
              : '';
          } else {
            this.isNew = true;
            formRegiao.NRCORPRIREGIAO = '#FFFFFF';
            formRegiao.NRPRATREGIAO = '';
            formRegiao.DTINATIVAUTO = '';
            formRegiao.QTPADRAOREGIAO = '';
          }
          LoadingService.hide();
        });
      }
    }
    
    this.getParamPlaneja();
  }
  
  public formatHour(valueHour: any) {
    const separator = ':';
    const sumHour = 0;
    
    let minutes: any = Math.round((valueHour - Math.floor(valueHour)) * 60);
    let hour: any = Math.floor(valueHour) + sumHour;
    minutes = minutes < 10 ? `0${minutes}` : minutes;
    hour = hour < 10 ? `0${hour}` : hour;
    
    const hourString = hour + separator + minutes;
    return hourString;
  }
  
  public requiredQtd({ component }: IEventParam<Select>) {
    const tab = this.setNameTab;
    let form;
    let qtd: any;
    if (tab === 'subTabReceitaPadrao') {
      form = Metadata.getInstance<Form>('formDadosReceita');
      qtd = form?.getChildInstance('QTMEDICASEPRATPADR');
    } else if (tab === 'subTabReceitaLocal') {
      form = Metadata.getInstance<Form>('formDadosReceitaLocal');
      qtd = form?.getChildInstance('QTMEDICASEPRATFILI');
    } else if (tab === 'subTabReceitaServico') {
      form = Metadata.getInstance<Form>('formDadosReceitaServico');
      qtd = form?.getChildInstance('QTMEDICASEPRATSERV');
    } else if (tab === 'subTabReceitaTipoCard') {
      form = Metadata.getInstance<Form>('formDadosReceitaTipoCard');
      qtd = form?.getChildInstance('QTMEDICASEPRATPADR');
    }
    
    if (component.value === undefined || component.value === null || component.value === '') {
      qtd.removeValidation('required');
      qtd.value = null;
      qtd.disabled = true;
    } else {
      qtd.disabled = false;
    }
  }
  
  public disableButtonsRecipeTrue() {
    const tab = this.setNameTab;
    let cancel;
    let save;
    if (tab === 'subTabReceitaPadrao') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipePadrao');
      save = Metadata.getInstance<Button>('saveButtonRecipePadrao');
    } else if (tab === 'subTabReceitaLocal') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeLocal');
      save = Metadata.getInstance<Button>('saveButtonRecipeLocal');
    } else if (tab === 'subTabReceitaServico') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeServico');
      save = Metadata.getInstance<Button>('saveButtonRecipeServico');
    } else if (tab === 'subTabReceitaTipoCard') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeTpCard');
      save = Metadata.getInstance<Button>('saveButtonRecipeTpCard');
    } else if (tab === 'subTabReceitaPadraoQualidade') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipePadraoQualidade');
      save = Metadata.getInstance<Button>('saveButtonRecipePadraoQualidade');
    } else if (tab === 'subTabReceitaRegiao') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeRegiao');
      save = Metadata.getInstance<Button>('saveButtonRecipeRegiao');
    }
    
    if (cancel) cancel.disabled = true;
    if (save) save.disabled = true;
    this.setValuesRecipe();
  }
  
  public disableButtonsRecipeFalse() {
    const tab = this.setNameTab;
    let cancel;
    let save;
    if (tab === 'subTabReceitaPadrao') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipePadrao');
      save = Metadata.getInstance<Button>('saveButtonRecipePadrao');
    } else if (tab === 'subTabReceitaLocal') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeLocal');
      save = Metadata.getInstance<Button>('saveButtonRecipeLocal');
    } else if (tab === 'subTabReceitaServico') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeServico');
      save = Metadata.getInstance<Button>('saveButtonRecipeServico');
    } else if (tab === 'subTabReceitaTipoCard') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeTpCard');
      save = Metadata.getInstance<Button>('saveButtonRecipeTpCard');
    } else if (tab === 'subTabReceitaPadraoQualidade') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipePadraoQualidade');
      save = Metadata.getInstance<Button>('saveButtonRecipePadraoQualidade');
    } else if (tab === 'subTabReceitaRegiao') {
      cancel = Metadata.getInstance<Button>('cancelButtonRecipeRegiao');
      save = Metadata.getInstance<Button>('saveButtonRecipeRegiao');
    }
    
    if (cancel) cancel.disabled = false;
    if (save) save.disabled = false;
  }
  
  public validDateInactivation() {
    const tab = this.setNameTab;
    let form;
    if (tab === 'subTabReceitaPadrao') form = Metadata.getInstance<Form>('formDadosReceita').value;
    else if (tab === 'subTabReceitaLocal') form = Metadata.getInstance<Form>('formDadosReceitaLocal').value;
    else if (tab === 'subTabReceitaServico') form = Metadata.getInstance<Form>('formDadosReceitaServico').value;
    else if (tab === 'subTabReceitaTipoCard') form = Metadata.getInstance<Form>('formDadosReceitaTipoCard').value;
    else if (tab === 'subTabReceitaPadraoQualidade') {
      form = Metadata.getInstance<Form>('formDadosReceitaPadraoQualidade').value;
    } else if (tab === 'subTabReceitaRegiao') form = Metadata.getInstance<Form>('formDadosReceitaRegiao').value;

    let date;
    date = form?.DTINATIVAUTO;
    
    if (date) {
      if (moment(date, 'DD/MM/YYYY').isAfter(moment())) return true;
      this.utilities.showAlert('alert', 'Data de Inativação deve ser maior que a atual.', 'error');
      date = '';
      return false;
    }
    return true;
  }
}
