import {
  ModalService, Modal, Form, Select, GridEditable, IButtonEvent, IComponentRender, Button, Radio, Grid, DialogService,
  LoadingService,
} from '@zeedhi/common';
import {
  Loader, Metadata, IEventParam, IDictionary, Http,
} from '@zeedhi/core';

export class Pla01309RevisaoAutomaticaController {
  private utilities = Loader.getInstance('Utilities');
  
  private utilitiesPLA = Loader.getInstance('UtilitiesPLA');
  
  public appController = Loader.getInstance('AppController');
  
  public modalRevisaoAutoReceitas!: Modal;
  
  public prato = Loader.getInstance('Pla01300PratoController');
  
  public gridEditableController = Loader.getInstance('GridEditableController');
  
  private async createModalRevisaoAutoReceitas() {
    this.modalRevisaoAutoReceitas = await ModalService.createFromJsonPost('',
      { jsonPath: 'planejamento/prato/modals/pla01309_revisao_auto_receitas' });
  }
    
  public closeModalRevisaoAutoReceitas() {
    this.clearModalFields();
    this.modalRevisaoAutoReceitas.hide();
    this.modalRevisaoAutoReceitas.destroy();
    this.modalRevisaoAutoReceitas = this.utilities.modalEmpty;
  }
    
  public async openModalRevisaoAutoReceitas() {
    if (!this.modalRevisaoAutoReceitas) {
      this.createModalRevisaoAutoReceitas().then(() => {
        this.modalRevisaoAutoReceitas.show();
        this.clearModalFields();
      });
    } else {
      await this.modalRevisaoAutoReceitas.show();
      this.clearModalFields();
    }
  }
  
  public fullscreen({ component }: IButtonEvent) {
    this.modalRevisaoAutoReceitas.fullscreen = !this.modalRevisaoAutoReceitas.fullscreen;
    component.iconName = (this.modalRevisaoAutoReceitas.fullscreen) ? 'mdi-fullscreen-exit' : 'mdi-fullscreen';
  }
  
  public inicContainerDestino() {
    // const project = localStorage.getItem('PRODUCT_ID');
    
    const tpReceitaCard = Metadata.getInstance<Select>('TPRECEITA');
    const tpReceita = Metadata.getInstance<Select>('TPRECEITA1');
    
    const tpReceitaDestCard = Metadata.getInstance<Select>('TPRECEITADEST');
    const tpReceitaDest = Metadata.getInstance<Select>('TPRECEITADEST1');

    const cardapio = Metadata.getInstance<Select>('TIPOCARD_ACAO');
    const cardapioDest = Metadata.getInstance<Select>('TIPOCARDDEST');
    
    const central = Metadata.getInstance<Select>('CENTRAL');
    const centralDest = Metadata.getInstance<Select>('CENTRALDESTINO');

    if (this.utilitiesPLA.isMerenda()) {
      tpReceitaCard.isVisible = true;
      tpReceita.isVisible = false;
      tpReceitaDestCard.isVisible = true;
      tpReceitaDest.isVisible = false;
      central.disabled = true;
      centralDest.disabled = true;
    } else {
      tpReceitaCard.isVisible = false;
      tpReceita.isVisible = true;
      tpReceitaDestCard.isVisible = false;
      tpReceitaDest.isVisible = true;
      cardapio.isVisible = false;
      cardapioDest.isVisible = false;
      central.isVisible = false;
      centralDest.isVisible = false;
    }
  }
  
  public setFilterServiceDest({ component }: IEventParam<Select>) {
    const form: Form = Metadata.getInstance('formFiltroRevAuto');
    const row = form.value;
    const conditions = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: row.UNIDADEDEST,
      },
      {
        name: 'IDTIPOSERV',
        operator: '=',
        value: this.utilitiesPLA.isMerenda() ? '' : 'N',
      },
    ];
    component.datasource.filter = conditions;
    component.datasource.get();
  }
  
  public changeRecipeRevisaoAuto({ component }: IEventParam<Select>) {
    const uni = document.getElementsByName('UNIDADEDEST');
    const tpc = document.getElementsByName('TIPOCARDDEST');
    const serv = document.getElementsByName('SERVICODEST');
    
    if (uni.length > 0 && tpc.length > 0 && serv.length > 0) {
      const filial = Metadata.getInstance<Select>('UNIDADEDEST');
      const cardapio = Metadata.getInstance<Select>('TIPOCARDDEST');
      const servico = Metadata.getInstance<Select>('SERVICODEST');
      const central = Metadata.getInstance<Select>('CENTRALDESTINO');
  
      if (component.value === 'L') {
        filial.disabled = false;
        filial.addValidation('required', { message: 'Campo obrigatório' });
        filial.setValue('');
        servico.disabled = true;
        servico.removeValidation('required');
        servico.setValue('');
        cardapio.disabled = true;
        cardapio.removeValidation('required');
        cardapio.setValue('');
        central.disabled = true;
        central.removeValidation('required');
        central.setValue('');
      } else if (component.value === 'T') {
        filial.disabled = true;
        filial.removeValidation('required');
        filial.setValue('');
        servico.disabled = true;
        servico.removeValidation('required');
        servico.setValue('');
        cardapio.addValidation('required', { message: 'Campo obrigatório' });
        cardapio.disabled = false;
        central.addValidation('required', { message: 'Campo obrigatório' });
        central.disabled = !this.prato.permiteSelecCentral;
        central.setValue(this.appController.getCdCentral());
      } else if (component.value === 'S') {
        filial.disabled = false;
        servico.disabled = false;
        cardapio.disabled = true;
        central.disabled = true;
        filial.addValidation('required', { message: 'Campo obrigatório' });
        servico.addValidation('required', { message: 'Campo obrigatório' });
        cardapio.removeValidation('required');
        cardapio.setValue('');
        central.removeValidation('required');
        central.setValue('');
      } else if (component.value === 'P') {
        // this.prato.searchOpLogado(component);
        // fazer verificacao pro opLogado
        filial.removeValidation('required');
        servico.removeValidation('required');
        cardapio.removeValidation('required');
        central.removeValidation('required');
        filial.disabled = true;
        servico.disabled = true;
        cardapio.disabled = true;
        central.disabled = true;
        filial.setValue('');
        servico.setValue('');
        cardapio.setValue('');
        central.setValue('');
      }
    }
  }
  
  public saveRevisaoAutomatica() {
    const form = Metadata.getInstance<Form>('formAcoesPrato');
    const grid: GridEditable = Metadata.getInstance('gridPrato');
    const editedRows = grid.getEditedRows() as IDictionary;
    if (form.validate()) {
      if (editedRows.length > 0) {
        this.utilities.showAlert('alert', 'Salvo com sucesso!', 'success');
        this.atualizarGridRevisaoAutomatica();
      } else {
        this.gridEditableController.cancelEditing({ component: grid });
        this.utilities.showAlert('alert', 'Nenhum registro editado.', 'error');
      }
    }
  }
  
  public atualizarGridRevisaoAutomatica() {
    const grid: GridEditable = Metadata.getInstance('gridPrato');
    const editedRows = grid.getEditedRows() as IDictionary;
    editedRows.forEach((editedRow: IDictionary) => {
      if (editedRow.QUANTIDADE !== editedRow.QTDANTERIOR && editedRow.QUANTIDADE >= 0) {
        editedRow.PROPORCAO = editedRow.QUANTIDADE / editedRow.QTDANTERIOR;
      }
      
      const foundIndex = grid.datasource.data.findIndex((plate: IDictionary) => plate.PK === editedRow.PK);
      grid.datasource.data[foundIndex].PROPORCAO = editedRow.PROPORCAO;
      grid.datasource.data[foundIndex].QUANTIDADE = editedRow.QUANTIDADE;
    });
    grid.editing = false;
    const toolbarSlot = grid.toolbarSlot;
    toolbarSlot.forEach((e: IComponentRender) => {
      if (e.name === 'cancelButton') e.disabled = !e.disabled;
      if (e.name === 'saveButton') e.disabled = !e.disabled;
    });
  }
  
  public confirmarAcoesRevisaoAutomatica({ component }: IEventParam<Button>) {
    const grid: GridEditable = Metadata.getInstance('gridPrato');
    if (grid.editing === true) {
      DialogService.show({
        name: 'alteracoesSemSalvar',
        type: 'warning',
        title: 'Atenção',
        text: 'Há alterações sem salvar. Deseja salvar as alterações antes de continuar?',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => { this.saveRevisaoAutomatica(); this.validateRevisaoReceita(component); } },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: {
              click: () => {
                this.gridEditableController.cancelEditing({ component: grid });
                this.validateRevisaoReceita(component);
              },
            },
          },
        ],
      });
    } else {
      this.validateRevisaoReceita(component);
    }
  }
  
  public validateRevisaoReceita(component: any) {
    DialogService.hide();
    const form: Form = Metadata.getInstance('formAcoesPrato');
    const row = form.value;
    const form2: Form = Metadata.getInstance('formFiltroRevAuto');
    const row2 = form2.value;
    const grid: GridEditable = Metadata.getInstance('gridPrato');
    const rowsGrid = grid.selectedRows;
    if (row.TPRECEITA === null) row.TPRECEITA = row.TPRECEITA1;
    if (row2.TPRECEITADEST === null) row2.TPRECEITADEST = row2.TPRECEITADEST1;
    const tpReceitaOrig = row.TPRECEITA;
    const tpReceitaDest = row2.TPRECEITADEST;
    const servOrig = row.SERVICO;
    const servDest = row2.SERVICODEST;
    if (row.TPRECEITA === 'L' && row2.TPRECEITADEST === 'L' && row.UNIDADE === row2.UNIDADEDEST) {
      this.utilities.showAlert('Alert', 'Unidade de destino deve ser diferente da unidade de origem!', 'error');
    } else if (tpReceitaOrig === 'S' && tpReceitaDest === 'S' && row.UNIDADE === row2.UNIDADEDEST && servOrig === servDest) {
      this.utilities.showAlert('Alert', 'Serviço de destino deve ser diferente do serviço de origem!', 'error');
    } else if (row.TPRECEITA === 'T' && row2.TPRECEITADEST === 'T' && row.TIPOCARD_ACAO === row2.TIPOCARDDEST
    && row.CENTRAL === row2.CENTRALDESTINO) {
      this.utilities.showAlert('Alert',
        'Tipo de Cardápio de destino deve ser diferente do tipo de cardápio de origem!',
        'error');
    } else if (row.TPRECEITA === 'P' && row2.TPRECEITADEST === 'P') {
      this.utilities.showAlert('Alert', 'Não é possível copiar pratos de origem padrão para destino padrão!', 'error');
    } else {
      let altQtd = 'N';
      rowsGrid.forEach((item: IDictionary) => {
        if (item.QUANTIDADE !== item.QTDANTERIOR) {
          altQtd = 'S';
        }
      });
      
      // row.CDFILCENTPME = this.appController.getCdCentral();
      row.CDFILCENTPME = row.CENTRAL;
      row2.CDFILCENTPME = row2.CENTRALDESTINO;
      
      if (form.validate() && form2.validate()) {
        if (rowsGrid.length > 0) {
          LoadingService.show(' ');
          if (row2.TPRECEITADEST === 'P') this.prato.searchOpLogado(component);
          if (row2.TPRECEITADEST !== 'P' || (row2.TPRECEITADEST === 'P' && this.prato.operatorValid !== false)) {
            const params = [row, row2, rowsGrid];
            
            if (altQtd === 'S') {
              DialogService.show({
                name: 'alterarQtProdutosProporcional',
                type: 'warning',
                title: 'Atenção',
                text: 'Deseja alterar proporcionalmente as quantidades dos produtos na receita?',
                buttons: [
                  {
                    name: 'yes',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: { click: () => { row2.ID_PROPORCAO = 'S'; this.callRevisaoReceita(params, component, grid); } },
                    outline: true,
                  },
                  {
                    name: 'no',
                    component: 'ZdButton',
                    label: 'Não',
                    events: { click: () => { row2.ID_PROPORCAO = 'N'; this.callRevisaoReceita(params, component, grid); } },
                  },
                ],
              });
            } else {
              row2.ID_PROPORCAO = 'N';
              this.callRevisaoReceita(params, component, grid);
            }
          } else {
            this.utilities.showAlert('Alert', 'Modificação em receita padrão depende de autorização.', 'warning');
            this.prato.openModalGroupOperador(component);
          }
        } else {
          this.utilities.showAlert('Alert', 'Ao menos um prato deve ser selecionado', 'error');
          // this.utilities.disableLoadingButton(component);
          LoadingService.hide();
        }
      }
    }
  }
  
  public callRevisaoReceita(params: IDictionary, component: any, grid: GridEditable) {
    LoadingService.show(' ');
    Http.post('/revisarReceita', { requestType: 'Row', row: params }).then((response) => {
      if (response.data) {
        if (response.data.dataset) {
          if (response.data.dataset.REVISAO[0]) {
            this.utilities.showAlert('alert', 'Salvo com sucesso!', 'success');
            grid.cancelEditedRows();
          }
        } else this.utilities.showAlert('alert', `pme::${response.data.error}`, 'error');
      }
    }).catch((error: string) => {
      this.utilities.showAlert('alert', `pme::${error}`, 'error');
    }).finally(() => {
      LoadingService.hide();
      grid.selectedRows = [];
      DialogService.hide();
    });
  }
  
  public clearModalFields() {
    const fields = [
      'TIPOCARD_ACAO', 'CENTRAL', 'TIPOCARDDEST', 'CENTRALDESTINO',
      'UNIDADEDEST', 'SERVICODEST', 'SERVICO', 'UNIDADE', 'PRATOINICIAL',
      'PRATOFINAL',
    ];
    fields.forEach((fieldName) => {
      if (document.getElementsByName(fieldName).length > 0) Metadata.getInstance<Select>(fieldName).setValue('');
    });
    
    if (document.getElementsByName('TPRECEITA').length > 0) Metadata.getInstance<Select>('TPRECEITA').setValue('P');
    if (document.getElementsByName('TPRECEITA1').length > 0) Metadata.getInstance<Select>('TPRECEITA1').setValue('P');
    if (document.getElementsByName('TPRECEITADEST').length > 0) Metadata.getInstance<Select>('TPRECEITADEST').setValue('P');
    if (document.getElementsByName('TPRECEITADEST1').length > 0) {
      Metadata.getInstance<Select>('TPRECEITADEST1').setValue('P');
    }
    
    if (document.getElementsByName('gridPrato').length > 0) {
      const gridPrato: Grid = Metadata.getInstance('gridPrato');
      gridPrato.datasource.data = [];
      gridPrato.datasource.total = 0;
      gridPrato.datasource.filter = [];
      gridPrato.selectedRows = [];
    }
    
    if (document.getElementsByName('IMPORTTYPE').length > 0) Metadata.getInstance<Radio>('IMPORTTYPE').value = 'ACRESCENTAR';
  }
}
