import {
  Loader, Metadata, IEventParam, IDictionary, Config,
} from '@zeedhi/core';
import {
  Form, Select, Button, CheckboxMultiple,
} from '@zeedhi/common';
import { PmeMask } from '@/config';

export class Pme01600DesvioDeConsumoController {
  public reportController = Loader.getInstance('ReportController');

  public appController = Loader.getInstance('AppController');

  public utilities = Loader.getInstance('Utilities');
  
  public modalController = Loader.getInstance('ModalController');

  public defaultReport({ component }: IEventParam<Select>) {
    component.setValue(component.datasource.data[0]);
  }
  
  private impTipoProduto = {
    ESTOCAVEIS: 'S',
    NAOESTOCAVEIS: 'S',
  };
  
  private setParams(row: IDictionary) {
    const mask: string = (Config.masks.productMask as PmeMask).pattern;
    row.CDTIPOCUSTO = row.TIPOCUSTO.CDTIPOCUSTO;
    row.NMTIPOCUSTO = row.TIPOCUSTO.NMTIPOCUSTO;
    row.CDSERVFILI = row.SERVICO ? row.SERVICO : null;
    row.CDFILIAL = row.UNIDADE ? row.UNIDADE : null;
    row.CDFILCENTPME = this.appController.getCdCentral();
    row.NMFILCENTPME = this.appController.getNmCentral();
    row.TAMACNIVEL = this.utilities.calcTamacNivel(row.NIVEL, 'produto');
    row.ESTOCAVEIS = this.impTipoProduto.ESTOCAVEIS;
    row.NAOESTOCAVEIS = this.impTipoProduto.NAOESTOCAVEIS;
    row.REPORT_NAME = row.REPORT.REPORT_NAME;
    row.CD_REPORT_CODE = row.REPORT.CD_REPORT_CODE;
    row.CDPICTPROD = this.utilities.formatReportMask(mask);
    row.AGRUPMASK = this.utilities.getReportMaskNivel(mask, row.NIVEL);
    row.DTMESINIC = row.DTDE;
    row.DTMESFINA = row.DTATE;
  }
  
  public generateReport({ component }: IEventParam<Button>) {
    const form = Metadata.getInstance<Form>('FORM');
    const tipoProduto = Metadata.getInstance<CheckboxMultiple>('TIPOPRODUTO');

    if (this.utilities.centralIsValid() && this.reportController.formIsValid(form)) {
      const row: IDictionary = form.value;
      
      this.setParams(row);
      if (row.CDFILCENTPME == null) this.utilities.showAlert('alertError', 'Central não informada.', 'error');
      else if (tipoProduto.value.length === 0) {
        this.utilities.showAlert('alertError', 'Tipo de Produto deve ser informado.', 'error');
      
      /* const dtFinMax = moment(row.DTDE, 'DD/MM/YYYY').add(15, 'd');
      if ((row.GRUPFILI == null && row.UNIDADE.length === 0 && row.GRUPOSERVICO == null && row.SERVICO.length === 0)
          || (row.DTDE !== row.DTATE && moment(row.DTATE, 'DD/MM/YYYY') > dtFinMax)) {
        DialogService.show({
          name: 'confirmReport',
          type: 'warning',
          title: 'Atenção',
          text: 'Caso não seja definido opções de filtro ou informar um período superior a 15 '+
          'dias o processamento pode demorar. Deseja continuar?',
          buttons: [
            {
              name: 'yes',
              component: 'ZdButton',
              label: 'Sim',
              events: { click: () => this.reportController.callGenerateReport(component, row, 'report/desvioDeConsumo') },
              outline: true,
            },
            {
              name: 'no',
              component: 'ZdButton',
              label: 'Não',
              events: { click: () => DialogService.hide() },
            },
            {
              name: 'progressLine',
              component: 'ZdProgress',
              label: 'Progress',
              indeterminate: true,
              cssClass: 'loading-progress-line',
            },
          ],
        });
      } */
      } else {
        this.reportController.callGenerateReport(component, row, 'report/desvioDeConsumo');
      }
    }
  }
  
  public setTipoProduto({ component }: IEventParam<CheckboxMultiple>) {
    if (component.value) {
      const items = component.value.join('_');
      if (items.includes('ESTOCAVEIS')) this.impTipoProduto.ESTOCAVEIS = 'S';
      else this.impTipoProduto.ESTOCAVEIS = 'N';

      if (items.includes('NAOESTOC')) this.impTipoProduto.NAOESTOCAVEIS = 'S';
      else this.impTipoProduto.NAOESTOCAVEIS = 'N';
    }
  }
}
